package com.ruoyi.learn.service;

import java.util.List;
import com.ruoyi.learn.domain.LearnKnowledgeTree;
import com.ruoyi.learn.domain.LearnKnowledgeTree2;

/**
 * 知识点树Service接口
 * 
 * @author ruoyi
 * @date 2025-09-25
 */
public interface ILearnKnowledgeTreeService 
{
    /**
     * 查询知识点树
     * 
     * @param id 知识点树主键
     * @return 知识点树
     */
    public LearnKnowledgeTree selectLearnKnowledgeTreeById(Long id);

    /**
     * 批量查询知识点树
     * 
     * @param ids 知识点树主键列表
     * @return 知识点树集合
     */
    public List<LearnKnowledgeTree> selectLearnKnowledgeTreeByIds(List<Long> ids);

    /**
     * 查询知识点树列表
     * 
     * @param learnKnowledgeTree 知识点树
     * @return 知识点树集合
     */
    public List<LearnKnowledgeTree> selectLearnKnowledgeTreeList(LearnKnowledgeTree learnKnowledgeTree);

    /**
     * 新增知识点树
     * 
     * @param learnKnowledgeTree 知识点树
     * @return 结果
     */
    public int insertLearnKnowledgeTree(LearnKnowledgeTree learnKnowledgeTree);

    /**
     * 修改知识点树
     * 
     * @param learnKnowledgeTree 知识点树
     * @return 结果
     */
    public int updateLearnKnowledgeTree(LearnKnowledgeTree learnKnowledgeTree);

    /**
     * 批量删除知识点树
     * 
     * @param ids 需要删除的知识点树主键集合
     * @return 结果
     */
    public int deleteLearnKnowledgeTreeByIds(Long[] ids);

    /**
     * 删除知识点树信息
     * 
     * @param id 知识点树主键
     * @return 结果
     */
    public int deleteLearnKnowledgeTreeById(Long id);

    /**
     * 根据题目ID列表查询知识点树
     * 
     * @param questionIds 题目ID列表
     * @return 知识点树集合（包含题目ID）
     */
    public List<LearnKnowledgeTree2> selectLearnKnowledgeByQuestionIds(List<Long> questionIds);

    /**
     * 根据知识点ID列表查询知识点树
     * 
     * @param knowledgeIds 知识点ID列表
     * @return 知识点树集合（包含题目ID）
     */
    public List<LearnKnowledgeTree2> selectLearnKnowledgeByKnowledgeIds(List<Long> knowledgeIds);
}
